package taxeze;

import java.lang.reflect.*;
import javax.swing.*;

import taxeze.gui.*;

/**
 * The main class for Taxeze.
 * 
 * Note: Icons are courtesy of the GNOME project.
 *
 * @author Prof. David Bernstein, James Madison University
 */
public class Taxeze implements Runnable
{
  /**
   * The entry point of the application.
   * 
   * @param args  The command-line arguments (which are ignored)
   * @throws InterruptedException If the system is interrupted
   * @throws InvocationTargetException If there is a problem starting the system
   */
  public static void main(String[] args) throws InterruptedException, InvocationTargetException
  {
    // Perform all of the setup activities in the event dispatch thread
    SwingUtilities.invokeAndWait(new Taxeze());
  }
  
  /**
   * The code to execute in the event dispatch thread
   * (required by Runnable).
   */
  public void run()
  {
    setLookAndFeel();

    // Setup the application
    TaxezeController controller = new TaxezeController();
    TaxezeWindow window = new TaxezeWindow(controller);

    // Start the application
    window.setVisible(true);
  }

  /**
   * Set the look and feel for the application.
   */
  private void setLookAndFeel()
  {
    // Setup the look and feel
    boolean done = false;
    try 
    {
      // Use Nimbus if it is available
      UIManager.LookAndFeelInfo[] lfs = UIManager.getInstalledLookAndFeels();
      for (int i=0; i<lfs.length && !done; i++)
      {
        if ("Nimbus".equals(lfs[i].getName())) 
        {
          UIManager.setLookAndFeel(lfs[i].getClassName());
          done = true;
        }
      }

      // If Nimbus isn't available, use the system look and feel
      if (!done)
      {
        String lookAndFeel = UIManager.getSystemLookAndFeelClassName();
        UIManager.setLookAndFeel(lookAndFeel);
      }
    } 
    catch (ClassNotFoundException cnfe)
    {
      // Use the default look and feel
    }
    catch(IllegalAccessException iae)
    {
      // Use the default look and feel
    }
    catch (InstantiationException ie)
    {
      // Use the default look and feel
    }
    catch (UnsupportedLookAndFeelException ulale)
    {
      // Use the default look and feel
    }
  }
}
