package testing;

import static org.junit.jupiter.api.Assertions.*;

import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;

import org.junit.jupiter.api.Test;
import tax.*;

class Test_TaxTable
{

  @Test
  void getUninterpolatedRate()
  {
    double[] boundaries = {-0.01, 9700.00, 39475.00, 84200.00, 160725.00, 204100.00, 510300.00};
    double[] rates      = { 0.0,    10.0,     12.0,     22.0,      24.0,       32.0,      35.0,    37.0};
    
    TaxTable tt = new TaxTable();
    tt.setBoundaries(boundaries);
    tt.setRates(rates);
    
    assertEquals(10.0, tt.getUninterpolatedRate(   0.00), 0.001);
    assertEquals(10.0, tt.getUninterpolatedRate(3700.00), 0.001);
    assertEquals(10.0, tt.getUninterpolatedRate(9700.00), 0.001);
    
    assertEquals(12.0, tt.getUninterpolatedRate(39475.00), 0.001);

    assertEquals(22.0, tt.getUninterpolatedRate(39475.01), 0.001);
    assertEquals(22.0, tt.getUninterpolatedRate(42000.50), 0.001);
    assertEquals(22.0, tt.getUninterpolatedRate(84200.00), 0.001);
  }


  @Test
  void getInterpolatedRate()
  {
    double[] boundaries = {-0.01, 9700.00, 39475.00, 84200.00, 160725.00, 204100.00, 510300.00};
    double[] rates      = { 0.0,    10.0,     12.0,     22.0,      24.0,       32.0,      35.0,    37.0};
    
    TaxTable tt = new TaxTable();
    tt.setBoundaries(boundaries);
    tt.setRates(rates);
    
    assertEquals( 0.0, tt.getInterpolatedRate(   0.00), 0.001);
    assertEquals( 5.0, tt.getInterpolatedRate(4850.00), 0.001);
    assertEquals(10.0, tt.getInterpolatedRate(9700.00), 0.001);
    
    assertEquals(12.0, tt.getInterpolatedRate(39475.00), 0.001);

    assertEquals(12.00000, tt.getInterpolatedRate(39475.01), 0.001);
    assertEquals(12.56467, tt.getInterpolatedRate(42000.50), 0.001);
    assertEquals(22.0, tt.getInterpolatedRate(84200.00), 0.001);

    assertEquals(33.5, tt.getInterpolatedRate(357200.00), 0.001);

    assertEquals(35.0, tt.getInterpolatedRate(510300.00), 0.001);
    
    assertEquals(37.0, tt.getInterpolatedRate(510300.01), 0.001);
    assertEquals(37.0, tt.getInterpolatedRate(600000.00), 0.001);
    
  }

  @Test
  void getUninterpolatedTax()
  {
    double[] boundaries = {-0.01, 9700.00, 39475.00, 84200.00, 160725.00, 204100.00, 510300.00};
    double[] rates      = { 0.0,    10.0,     12.0,     22.0,      24.0,      32.0,      35.0,    37.0};
    
    TaxTable tt = new TaxTable();
    tt.setBoundaries(boundaries);
    tt.setRates(rates);
    
    assertEquals(    0.00, tt.getUninterpolatedTax(      0.00), 0.001);
    assertEquals(  370.00, tt.getUninterpolatedTax(   3700.00), 0.001);
    assertEquals(  970.00, tt.getUninterpolatedTax(   9700.00), 0.001);
    
    assertEquals( 4543.00, tt.getUninterpolatedTax(  39475.00), 0.001);

    assertEquals( 5098.50, tt.getUninterpolatedTax( 42000.00), 0.001);
    assertEquals(45316.50, tt.getUninterpolatedTax(200000.00), 0.001);
  }

  @Test
  void getInterpolatedTax()
  {
    double[] boundaries = {-0.01, 9700.00, 39475.00, 84200.00, 160725.00, 204100.00, 510300.00};
    double[] rates      = { 0.0,    10.0,     12.0,     22.0,      24.0,      32.0,      35.0,    37.0};
    
    TaxTable tt = new TaxTable();
    tt.setBoundaries(boundaries);
    tt.setRates(rates);
    
    assertEquals(    0.00, tt.getInterpolatedTax(      0.00), 0.001);
    assertEquals(  242.50, tt.getInterpolatedTax(   4850.00), 0.001);
    assertEquals(  970.00, tt.getInterpolatedTax(   9700.00), 0.001);
    
    assertEquals( 4543.00, tt.getInterpolatedTax(  39475.00), 0.001);

    assertEquals( 4860.2552, tt.getInterpolatedTax( 42000.00), 0.001);
    assertEquals(45019.5040, tt.getInterpolatedTax(200000.00), 0.001);
  }
  
  @Test
  void read() throws IOException
  {
    String PATH = "/home/bernstdh/jmu/bernsteinmaterials/scaffolding/Single_2019";
    TaxTable tt = new TaxTable();
    tt.read(PATH);
    assertEquals(12.56467, tt.getInterpolatedRate(42000.50), 0.001);
    assertEquals( 4860.2552, tt.getInterpolatedTax( 42000.00), 0.001);
  }
}
